local dewdrop = AceLibrary("Dewdrop-2.0")
local tablet = AceLibrary("Tablet-2.0")
local crayon = AceLibrary("Crayon-2.0");
local L = AceLibrary("AceLocale-2.2"):new("FuBar_MarkOfHonorFu")

MarkOfHonorFu = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0", "FuBarPlugin-2.0")
MarkOfHonorFu:RegisterDB("MarkOfHonorFuDB")


MarkOfHonorFu.hasIcon = format("%s%s", "Interface\\PvPRankBadges\\PvPRank", UnitFactionGroup("player"))
MarkOfHonorFu.version = "v20200.01." .. string.sub("$Revision: 1 $", 12, -3)
MarkOfHonorFu.date = string.sub("$Date: 2007-01-29 $", 8, 17)
MarkOfHonorFu.defaultPosition = 'RIGHT'
MarkOfHonorFu.initialized=false;

MarkOfHonorFu.Marks = {
	{Name=L["Alterac Valley Mark of Honor"],ShortName=L["AV"],Count=0,maxMarks=100},
	{Name=L["Arathi Basin Mark of Honor"],ShortName=L["AB"],Count=0,maxMarks=100},
	{Name=L["Warsong Gulch Mark of Honor"],ShortName=L["WSG"],Count=0,maxMarks=100},
	{Name=L["Eye of the Storm Mark of Honor"],ShortName=L["EotS"],Count=0,maxMarks=100},

--	{Name=L["Mark of Hellfire Peninsula"],ShortName=L["MoHP"],Count=0,maxMarks=100},
	
--	{Name=L["Mark of Thrallmar"],ShortName=L["MoT"],Count=0,maxMarks=250},
--	{Name=L["Mark of Honor Hold"],ShortName=L["MoHH"],Count=0,maxMarks=250},
}
	
function echo (msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg, 255, 255, 255);
end;

function MarkOfHonorFu:OnInitialize()
	if not self.initialized then
		self.initialized = TRUE
		self.class = UnitClass("player")
		self.faction = UnitFactionGroup("player")

		self:RegisterDefaults('profile', {
			showShortNames = true,
		})
	end
	self.timeSinceLastUpdate = 0
end

function MarkOfHonorFu:OnEnable()
	self:RegisterBucketEvent("BAG_UPDATE", 1, "Update")
end

function MarkOfHonorFu:Disable()
end

function MarkOfHonorFu:Report()
	self.cmd:report({
		{text=L["short"], val=(self.db.profile.showShortNames and 1 or 0), map=FuBarLocals.MAP_ONOFF},
	})
end

function MarkOfHonorFu:OnDataUpdate()
	self:GetMarks();
end

function MarkOfHonorFu:OnTextUpdate()
	self:SetIcon(hasIcon);

	local count_string = " "
	local color
	local postfix
	local prefix
	local Marks = self:GetMarks();

	for index,value in pairs(self.Marks) do
		color = crayon:GetThresholdHexColor( (self.Marks[index]["maxMarks"] - self.Marks[index]["Count"]) / self.Marks[index]["maxMarks"]);

		if self.db.profile.showShortNames then prefix=self.Marks[index]["ShortName"].." "; else prefix=""; end;
		postfix="/";

		count_string = format("%s%s|cff%s%d|r%s", count_string, prefix, color, self.Marks[index]["Count"], postfix);
	end;

	self:SetText(count_string);
	self:UpdateTooltip();
end

function MarkOfHonorFu:OnTooltipUpdate()
	local cat = tablet:AddCategory('columns', 2, 'child_textR', 0, 'child_textG', 1, 'child_textB', 0, "showWithoutChildren", false)

	local r, g, b
	
	for index,value in pairs(self.Marks) do
		r, g, b = crayon:GetThresholdColor((self.Marks[index]["maxMarks"]-self.Marks[index]["Count"])/self.Marks[index]["maxMarks"])
		cat:AddLine('text',format("%s%s",self.Marks[index]["Name"],":"), 'text2', self.Marks[index]["Count"], 'text2R', r, 'text2G', g, 'text2B', b)
	end;
end

function MarkOfHonorFu:GetMarks()
	for index,value in pairs(self.Marks) do
		self.Marks[index]["Count"]=0;
	end

	for bag = 4, 0, -1 do
		local size = GetContainerNumSlots(bag);
		if (size > 0) then
			for slot = 1, size, 1 do
				local _,itemCount = GetContainerItemInfo(bag, slot);
				if (itemCount) then
					local itemName = self:NameFromLink(GetContainerItemLink(bag, slot));
					if ((itemName) and (itemName ~= "")) then
						for index,value in pairs(self.Marks) do
							if (self.Marks[index]["Name"]==itemName) then
								self.Marks[index]["Count"]=self.Marks[index]["Count"]+itemCount;
							end;
						end
					end;
				end;
			end;
		end;
	end;
end

function MarkOfHonorFu:NameFromLink(link)
	if (link) then
		if (string.find(GetBuildInfo(), "^2%.")) then
			return GetItemInfo(link)
		else
			return GetItemInfo(tonumber(string.gsub(link, "|cff%x%x%x%x%x%x|Hitem:(%d+):%d+:%d+:%d+|h.*", "%1") or 0))
		end
	end
end

local optionsTable = {
	handler = MarkOfHonorFu,
	type = 'group',
	args = {
		shortnames = {
			type = 'toggle',
			name = L["Short names"],
			desc = L["Toggle showing short names in FuBar"],
			get = function() return MarkOfHonorFu.db.profile.showShortNames end,
			set = function()
				MarkOfHonorFu.db.profile.showShortNames = not MarkOfHonorFu.db.profile.showShortNames
				MarkOfHonorFu:Update()
			end,
		},
	}
}

MarkOfHonorFu:RegisterChatCommand({"/markofhonorfu", "/markofhonor", "/moh"}, optionsTable)
MarkOfHonorFu.OnMenuRequest = optionsTable
